@@ -92,7 +92,7 @@ X11::X11( std::string displayName ) {
     // Initialize display
     display = XOpenDisplay( displayName.c_str() );
     if ( !display ) {
-        throw new std::runtime_error(std::string("Error: Failed to open X display: ") + displayName );
+        throw std::runtime_error(std::string("Error: Failed to open X display: ") + displayName );
     }
     screen = ScreenOfDisplay( display, DefaultScreen( display ) );
     visual = DefaultVisual( display, XScreenNumberOfScreen( screen ) );
